# frozen_string_literal: true

require 'httparty'
require 'logger'

module Yade
  module Domain
    module Rest
      module Client
        include Yade::Common::Client

        # host client
        class HostClient < BaseClient
          include HTTParty
          #logger ::Logger.new(STDOUT), :debug

          base_uri Yade::Common::Config::AppConfig[:yade_url]

          def initialize
            super('yadedomain', 'host', 'Yade::Domain::Rest::Model::Host')
          end

          # get master host
          def master
            list.select(&:isMaster).first
          end

          # get host by fqdn
          def host_by_fqdn(host_fqdn)
            splitted = host_fqdn.split('.')

            hostname = splitted.first
            fqdn = splitted.last(splitted.size - 1).join('.')

            all_hosts_with_name = list.select { |h| h.name == hostname }

            domain_client = Yade::Domain::Rest::Client::DomainClient.new

            all_hosts_with_name.each do |h|
              domain = domain_client.get(h.domainId)
              return h if domain.name == fqdn
            end
          end
        end
      end
    end
  end
end